Py4JServerConnection (py4j-java 0.10.0 API)
Date: 2016-04-18

py4j

## Interface Py4JServerConnection

- All Known Implementing Classes:
    ClientServerConnection, GatewayConnection

      public interface Py4JServerConnection

- - ### Method Summary

    All Methods Instance Methods Abstract Methods
    Modifier and Type | Method and Description
    --- | ---
    `java.net.Socket` | `getSocket()`

- - ### Method Detail

    - #### getSocket

          java.net.Socket getSocket()

      Returns:
        The socket used by this gateway connection.